import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { useLocation, useNavigate } from 'react-router-dom';
import { Box, List, Toolbar, Tooltip, Typography, useMediaQuery, useTheme } from '@mui/material';
import Logo from '../../assets/images/logo.png';
import AdminNavBar from '../../components/navbar/AdminNavBar';
import { DrawerVariant } from '../../constants/common-constants';
import palette from '../../theme/colors';
import AppDrawer from './AppDrawer';
import './sidebar-styles.scss';
const SideBar = (props) => {
    const { brandLogo = '', children, routes = [], companyName = '' } = props;
    const navigate = useNavigate();
    const location = useLocation();
    const { pathname } = location;
    const theme = useTheme();
    const isMobile = useMediaQuery(theme.breakpoints.down('sm'));
    const [open, setOpen] = useState(false);
    const [drawerVariant, setDrawerVariant] = useState(isMobile ? DrawerVariant.Temporary : DrawerVariant.Permanent);
    const handleItemClick = (path) => {
        if (isMobile) {
            setDrawerVariant(() => DrawerVariant.Temporary);
            setOpen(() => false);
        }
        navigate(path);
    };
    const handleOpen = () => {
        setOpen(true);
    };
    const handleClose = () => {
        setOpen(false);
    };
    const handleHamburgerClick = () => {
        if (!isMobile)
            return;
        setDrawerVariant(() => (open ? DrawerVariant.Temporary : DrawerVariant.Permanent));
        setOpen(() => !open);
    };
    const renderListItems = () => (_jsx(List, { className: "sidebar__list", children: routes.map((item, index) => {
            const { icon: Icon, label, path } = item;
            const listItemClassName = pathname === path ? 'sidebar__listItemActive' : 'sidebar__listItem';
            const iconColor = pathname === path ? palette.primary : palette.textColor;
            return (_jsxs("div", { className: listItemClassName, onClick: () => handleItemClick(path), children: [_jsx(Icon, { style: {
                            color: iconColor,
                            fontSize: '22px',
                        }, height: 20, width: 20 }), _jsx(Tooltip, { title: label, children: _jsx(Typography, { color: iconColor, sx: {
                                opacity: open ? 1 : 0,
                                overflow: 'hidden',
                                textOverflow: 'ellipsis',
                                transition: open ? 'opacity 1000ms' : 'opacity 0ms',
                                whiteSpace: 'nowrap',
                            }, children: label }) })] }, `${label}-${index}`));
        }) }));
    useEffect(() => {
        setDrawerVariant(isMobile ? DrawerVariant.Temporary : DrawerVariant.Permanent);
    }, [isMobile]);
    return (_jsxs("div", { className: "sidebar__container", children: [_jsx(AdminNavBar, { handleHamburgerClick: handleHamburgerClick }), _jsxs(AppDrawer, { className: "sidebar__drawer", onMouseEnter: handleOpen, onMouseLeave: handleClose, open: open, variant: drawerVariant, children: [_jsxs("div", { className: "sidebar__logo", children: [_jsx("img", { alt: "logo", src: brandLogo || Logo, className: "sidebar__logoImage" }), _jsx(Typography, { className: "sidebar__logoText", sx: {
                                    opacity: open ? 1 : 0,
                                    transition: 'opacity 600ms',
                                }, children: companyName })] }), renderListItems()] }), _jsxs(Box, { component: "main", className: "sidebar__componentContainer", children: [_jsx(Toolbar, { className: "sidebar__componentToolbar" }), children] })] }));
};
export default SideBar;
