import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useCallback, useEffect, useMemo, useState } from 'react';
import { useDropzone } from 'react-dropzone';
import clsx from 'clsx';
import { Close as CloseIcon, Download as DownloadIcon, PhotoSizeSelectActualOutlined as GalleryIcon, InsertDriveFile as InsertDriveFileIcon, LibraryMusic as LibraryMusicIcon, PictureAsPdf as PictureAsPdfIcon, VideoLibrary as VideoLibraryIcon, } from '@mui/icons-material';
import { FormHelperText, Typography } from '@mui/material';
import IconButton from '@mui/material/IconButton';
import { downloadFile } from '../../utils';
import './adminUploader-style.scss';
const MIME_TYPES = {
    '.pdf': 'application/pdf',
    '.mp3': 'audio/mp3',
    '.mp4': 'video/mp4',
    '.jpg': 'image/jpeg',
    '.jpeg': 'image/jpeg',
    '.png': 'image/png',
};
const DEFAULT_ACCEPT = ['.jpg', '.jpeg', '.png', '.pdf', '.mp4', '.mp3'];
const AdminUploader = ({ multiple = false, accept = DEFAULT_ACCEPT, onChange, value, error = false, helperText = '', label = '', }) => {
    const [uploadedFiles, setUploadedFiles] = useState(!!value
        ? (Array.isArray(value) ? value : [value]).map(path => ({
            file: null,
            url: path,
        }))
        : []);
    const getAcceptTypes = useMemo(() => accept.reduce((acc, ext) => {
        if (MIME_TYPES[ext])
            acc[MIME_TYPES[ext]] = [ext];
        return acc;
    }, {}), [accept]);
    const createFilePreview = useCallback((file) => ['image', 'audio', 'video'].includes(file.type.split('/')[0])
        ? URL.createObjectURL(file)
        : undefined, []);
    const fileToBase64 = useCallback((file) => {
        return new Promise((resolve, reject) => {
            const reader = new FileReader();
            reader.readAsDataURL(file);
            reader.onload = () => resolve(reader.result);
            reader.onerror = error => reject(error);
        });
    }, []);
    const onDrop = useCallback(async (acceptedFiles) => {
        const base64Files = await Promise.all(acceptedFiles.map(file => fileToBase64(file)));
        const newFiles = acceptedFiles.map(file => ({
            file,
            url: createFilePreview(file) || '',
        }));
        const updatedFiles = multiple ? [...uploadedFiles, ...newFiles] : newFiles;
        console.log('updatedFiles', updatedFiles);
        setUploadedFiles(updatedFiles);
        onChange(multiple ? base64Files : base64Files[0]);
    }, [multiple, uploadedFiles, onChange, createFilePreview, fileToBase64]);
    const removeFile = useCallback((index) => () => {
        setUploadedFiles(files => {
            const updatedFiles = files.filter((_, i) => i !== index);
            return updatedFiles;
        });
    }, []);
    const handleFileDownload = useCallback((file, url) => () => {
        if (file) {
            const link = document.createElement('a');
            link.href = url;
            link.download = file.name || 'download';
            link.click();
        }
        else {
            downloadFile(file, url);
        }
    }, []);
    const renderFilePreviewIcon = useCallback((url, file) => {
        const type = file?.type.split('/')[0] || url.split('.').pop()?.toLowerCase();
        const icons = {
            video: _jsx(VideoLibraryIcon, { className: "adminUploader__icon" }),
            audio: _jsx(LibraryMusicIcon, { className: "adminUploader__icon" }),
            pdf: _jsx(PictureAsPdfIcon, { className: "adminUploader__icon" }),
            image: _jsx("img", { src: url, alt: `Preview`, className: "adminUploader__image" }),
        };
        return icons[type] || _jsx(InsertDriveFileIcon, { className: "adminUploader__icon" });
    }, []);
    const renderFiles = useCallback(() => {
        return (_jsx("div", { className: "adminUploader__previewContainer", children: uploadedFiles.map(({ file, url }, index) => (_jsxs("div", { className: "adminUploader__preview", children: [_jsxs("div", { className: "adminUploader__filePreview", children: [renderFilePreviewIcon(url, file), _jsx("p", { children: file?.name || url.split('/').pop() })] }), _jsxs("div", { className: "adminUploader__actions", children: [_jsx(IconButton, { onClick: removeFile(index), size: "small", "aria-label": `Remove ${file?.name || url}`, children: _jsx(CloseIcon, {}) }), _jsx(IconButton, { onClick: handleFileDownload(file, url), size: "small", "aria-label": `Download ${file?.name || url}`, children: _jsx(DownloadIcon, {}) })] })] }, index))) }));
    }, [uploadedFiles, renderFilePreviewIcon, removeFile, handleFileDownload]);
    const { getRootProps, getInputProps, isDragActive } = useDropzone({
        onDrop,
        accept: getAcceptTypes,
        multiple,
    });
    useEffect(() => {
        if (!!value) {
            const files = (Array.isArray(value) ? value : [value]).map(path => ({
                file: null,
                url: path,
            }));
            setUploadedFiles(files);
        }
    }, []);
    return (_jsxs("div", { className: "adminUploader__container", children: [_jsx(Typography, { className: "adminUploader__label", children: label }), _jsxs("div", { className: clsx('adminUploader__dropzone', {
                    adminUploader__dropzone__active: isDragActive,
                    adminUploader__dropzone__error: error,
                }), ...getRootProps(), children: [_jsx(GalleryIcon, { className: clsx('adminUploader__galleryIcon', {
                            adminUploader__galleryIcon__error: error,
                        }) }), _jsx("input", { ...getInputProps() }), _jsx(Typography, { className: "adminUploader__desc", children: isDragActive ? 'Drop the files here...' : 'Drag and drop files here, or click to upload' })] }), error && _jsx(FormHelperText, { className: "adminUploader__helperText", children: helperText }), !!uploadedFiles.length && renderFiles()] }));
};
export default AdminUploader;
