import { cast, flow, types } from 'mobx-state-tree';
import { HttpVerb, makeApiCall } from '../../../services/network/api-client';
const ConfigDataModel = types.model('ConfigDataModel', {
    id: types.string,
    key: types.string,
    value: types.frozen(),
    type: types.string,
});
const ConfigStore = types
    .model('ConfigStore', {
    configData: types.optional(types.array(ConfigDataModel), []),
    isConfigLoading: types.boolean,
})
    .actions(self => {
    const getConfigData = flow(function* getConfigData(page, limit) {
        try {
            self.isConfigLoading = true;
            const result = yield makeApiCall(HttpVerb.GET, `https://64c0c19c0d8e251fd11280d2.mockapi.io/venues?page=${page}&limit=${limit}`);
            console.log('result', result);
            self.configData = cast(result.data);
            self.isConfigLoading = false;
        }
        catch (e) {
            self.isConfigLoading = false;
            console.log('Error', e);
        }
        finally {
            self.isConfigLoading = false;
        }
    });
    const addConfigData = flow(function* updateConfigData(data) {
        if (Array.isArray(data.value)) {
            data.value = data.value.join(',');
        }
        try {
            const result = yield makeApiCall(HttpVerb.POST, 'https://64c0c19c0d8e251fd11280d2.mockapi.io/venues', data);
            console.log('result', result);
        }
        catch (e) {
            console.log('Error', e);
        }
        finally {
        }
    });
    const deleteConfigItem = flow(function* updateConfigData(id) {
        self.configData = cast(self.configData.filter(item => item.id !== id));
        const result = yield makeApiCall(HttpVerb.DELETE, `https://64c0c19c0d8e251fd11280d2.mockapi.io/venues/${id}`);
        console.log('result', result);
    });
    const updateConfigItem = flow(function* updateConfigData(id, newData) {
        const selectedItemIndex = self.configData.findIndex(item => item.id === id);
        self.configData[selectedItemIndex] = cast(newData);
        if (Array.isArray(newData.value)) {
            newData.value = newData.value.join(',');
        }
        try {
            const result = yield makeApiCall(HttpVerb.PUT, `https://64c0c19c0d8e251fd11280d2.mockapi.io/venues/${id}`, newData);
            console.log('result', result);
        }
        catch (e) {
            console.log('Error', e);
        }
        finally {
        }
    });
    return { getConfigData, deleteConfigItem, addConfigData, updateConfigItem };
});
export { ConfigStore };
