import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useState } from 'react';
import { observer } from 'mobx-react-lite';
import { AdminButton, AdminInput } from '../../components';
import { ButtonVariant, InputPresets } from '../../constants';
import { useStore } from '../../models';
import './registrationAdmin-styles.scss';
const RegistrationAdmin = observer((props) => {
    const { onClose } = props;
    const store = useStore();
    const { domainStore } = store;
    const { userStore } = domainStore;
    const { registerNewAdmin, isRegisterAdminLoading } = userStore;
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [errors, setErrors] = useState({
        email: '',
        password: '',
    });
    const handleEmailChange = (value) => {
        setEmail(String(value));
    };
    const handlePasswordChange = (value) => {
        setPassword(String(value));
    };
    const handleSuccessCallback = () => {
        setEmail('');
        setPassword('');
        onClose();
    };
    const handleRegistrationClick = async () => {
        try {
            if (!email || !password) {
                setErrors({
                    email: email ? '' : 'Email is required',
                    password: password ? '' : 'Password is required',
                });
                return;
            }
            registerNewAdmin(email, password, handleSuccessCallback);
        }
        catch (error) {
            console.log('Error', error);
        }
    };
    return (_jsxs("div", { className: "registrationPage__container", children: [_jsxs("div", { className: "registrationPage__form", children: [_jsx(AdminInput, { containerClass: "registrationPage__input", label: "Email", value: email, onChange: handleEmailChange, preset: InputPresets.Email, error: !!errors.email, helperText: errors.email }), _jsx(AdminInput, { containerClass: "registrationPage__input", label: "Password", value: password, onChange: handlePasswordChange, preset: InputPresets.Password, error: !!errors.password, helperText: errors.password })] }), _jsx(AdminButton, { isLoading: isRegisterAdminLoading, title: "Register", handleClick: handleRegistrationClick, buttonClass: "registrationPage__loginButton", variant: ButtonVariant.Outlined })] }));
});
export default RegistrationAdmin;
